@@ -1,58 +1,17 @@
-#' @title
-#' The ApotcData class
-#'
-#' @description
-#' `r lifecycle::badge("experimental")`
-#'
-#' An S4 class for storing information about T/B cell clonal expansion to be
-#' used by various [APackOfTheClones] functions. Instances of this object type
-#' are stored by [RunAPOTC] in a seurat object's `@misc` slot under a list named
-#' `"APackOfTheClones"`. This class is not meant to be directly instantiated,
-#' accessed, nor modified by the user. Attributes should only be accessed by the
-#' associated getters so its independent of implementation.
-#'
-#' @slot reduction_base character indicating the reduction the plotting was
-#' based off of.
-#' @slot clonecall character indicating the column name of the seurat object's
-#' metadata that contains the clone information.
-#' @slot metadata_filter_string character indicating the metadata filter string
-#' used to subset the seurat object before running APOTC.
-#' @slot clusters Clustered clones which is an R list of lists of length 5,
-#' with each list of length 5, with the first 3 elements being numeric vectors
-#' containing the x and y coordinates and radii of each clone in the cluster.
-#' The fourth element is a numeric vector of length 2 indicating the centroid of
-#' the cluster, and the fifth is the estimated cluster radius.
-#' @slot centroids Centroids of the clusters which default to the same centroids
-#' of the clusterlists, tho this also means clusters has to be iterated over
-#' everytime the plotting function is called. but it wont be slow probably
-#' @slot clone_sizes the original unscaled clone sizes for the samples.
-#' @slot clone_scale_factor scale factor to multiply `clone_sizes` by when
-#' running the clonal expansion plotting algorithms
-#' @slot rad_scale_factor scale factor to multiply the radii in clusterlists by
-#' after they have all been computed to increase spacing between circles. Might
-#' also be better in the future to instead just have a number to subtract :/
-#' @slot cluster_colors character vector indicating coloration of each cluster
-#' @slot reduction_base character indicating the reduction the plotting was
-#' based off of
-#' @slot label_coords list of numeric vectors of length two indicating the (x,y)
-#' coordinates of each label if plotted
-#'
-#' @keywords internal
-#' @noRd
-#'
 methods::setClass(
 	Class = "ApotcData",
 	slots = c(
 		reduction_base = 'character',
 		clonecall = 'character',
 		metadata_filter_string = 'character',
+		# could add ident_col but not really needed?
 
 		clusters = 'list',
 		centroids = 'list',
 		clone_sizes = 'list',
-		num_clusters = 'numeric',
+		idents = "character",
 
-		clone_scale_factor = 'numeric', # should make these overridable in APOTCPlot, and choose if they want to modify
+		clone_scale_factor = 'numeric',
 		rad_scale_factor = 'numeric',
 		cluster_colors = 'character',
 		labels = 'character',
@@ -60,64 +19,126 @@ methods::setClass(
 	)
 )
 
+# initialize the ApotcData object with all slots except clusters done
+# TODO a subsetted seurat object will probably have wrong colors
 ApotcData <- function(
-	seurat_obj, metadata_filter_condition, clonecall, reduction_base,
-	clone_scale_factor, rad_scale_factor
+	seurat_obj,
+	alt_ident,
+	metadata_filter_condition,
+	clonecall,
+	reduction_base,
+	clone_scale_factor,
+	rad_scale_factor
 ) {
-	if (identical(metadata_filter_condition, "")) {
-		return(initializeApotcData(
-			seurat_obj, clonecall, reduction_base, clone_scale_factor, rad_scale_factor
-		))
-	}
-	initializeSubsetApotcData(
-		seurat_obj, metadata_filter_condition, clonecall, reduction_base,
+
+	apotc_obj <- initializeApotcData(
+		seurat_obj, clonecall, metadata_filter_condition, reduction_base,
 		clone_scale_factor, rad_scale_factor
 	)
+	
+	seurat_obj <- set_meta_ident_col(seurat_obj, alt_ident)
+
+	apotc_obj <- addIdentsLabelsColors(apotc_obj, seurat_obj)
+
+	if (!identical(metadata_filter_condition, "")) {
+		seurat_obj <- subsetSeuratMetaData(
+			seurat_obj, metadata_filter_condition
+		)
+	}
+
+	seurat_obj <- ident_into_seurat_clusters(seurat_obj)
+
+	apotc_obj %>%
+		addRawClusteredCloneSizes(seurat_obj) %>%
+		addInitialCentroids(seurat_obj)
 }
 
 initializeApotcData <- function(
-	seurat_obj, clonecall, reduction_base, clone_scale_factor, rad_scale_factor
+	seurat_obj, clonecall, filter_string, reduction_base,
+	clone_scale_factor, rad_scale_factor
 ) {
-	num_clusters <- get_num_total_clusters(seurat_obj) # may need to redo, will leave empty elements for invalid clusters
-	initial_centroids <- get_cluster_centroids(seurat_obj, reduction_base)
-	raw_all_clone_sizes <- count_raw_clone_sizes(
-		seurat_obj = seurat_obj, num_clusters = num_clusters, clonecall = clonecall
-	)
-
 	methods::new(
 		Class = "ApotcData",
 
 		reduction_base = reduction_base,
 		clonecall = clonecall,
-		metadata_filter_string = "",
+		metadata_filter_string = filter_string,
 
 		clusters = list(),
-		centroids = initial_centroids,
-		clone_sizes = raw_all_clone_sizes,
-		num_clusters = num_clusters,
+		centroids = list(),
+		clone_sizes = list(),
+		idents = character(0),
 
 		clone_scale_factor = clone_scale_factor,
 		rad_scale_factor = rad_scale_factor,
-		cluster_colors = gg_color_hue(num_clusters),
-		labels = gen_labels(num_clusters),
-		label_coords = initial_centroids
+		cluster_colors = character(0),
+		labels = character(0),
+		label_coords = list()
 	)
 }
 
-# create subset / new obj based on new conditions, assuming valid!
-# based on an initialized (not nessecarily packed) apotc obj
-# assumes metadata_filter_condition cannot be null
+# terrible hack fix to set seurat_clusters column to active ident or alt_ident
+# so that the cluster counting is consistent - assumes alt_ident is valid
+# the output is a seurat obj with a new column in the metadata called
+# __active.ident__ that is guaranteed to be a factor with unguaranteed level type
+set_meta_ident_col <- function(seurat_obj, alt_ident) {
 
-initializeSubsetApotcData <- function(
-	seurat_obj, metadata_filter_condition, clonecall, reduction_base,
-	clone_scale_factor, rad_scale_factor
-) {
-	seurat_obj %>%
-		subsetSeuratMetaData(metadata_filter_condition) %>%
-		initializeApotcData(
-			clonecall, reduction_base, clone_scale_factor, rad_scale_factor
-		) %>%
-		set_metadata_filter_string(metadata_filter_condition)
+    if (is.null(alt_ident)) {
+        seurat_obj@meta.data[["__active.ident__"]] <- seurat_obj@active.ident
+        return(seurat_obj)
+    }
+
+    seurat_obj@meta.data[["__active.ident__"]] <- as.factor(
+        seurat_obj@meta.data[[alt_ident]]
+    )
+
+    seurat_obj
+}
+
+# finish the idents and num_clusters slot
+# apotc_obj must be a product of initializeApotcData
+# seurat_obj must be a product of set_meta-ident_col
+addIdentsLabelsColors <- function(apotc_obj, seurat_obj) {
+
+	apotc_obj <- set_idents(
+		apotc_obj, levels(seurat_obj@meta.data[["__active.ident__"]])
+	)
+
+	apotc_obj <- set_cluster_colors(
+		apotc_obj, gg_color_hue(get_num_clusters(apotc_obj))
+	)
+
+	if (have_default_idents(apotc_obj)) {
+		return(set_labels(apotc_obj, gen_labels(get_num_clusters(apotc_obj))))
+	}
+
+	set_labels(apotc_obj, get_idents(apotc_obj))
+}
+
+# important function to be ran after setting meta ident col
+# to merge that temporary column into seurat_clusters column
+ident_into_seurat_clusters <- function(seurat_obj) {
+    idents <- seurat_obj@meta.data[["__active.ident__"]]
+    seurat_obj@meta.data[["__active.ident__"]] <- NULL
+    seurat_obj@meta.data$seurat_clusters <- idents
+    seurat_obj
+}
+
+# seurat obj has seurat clusters column with correct idents
+addRawClusteredCloneSizes <- function(apotc_obj, seurat_obj) {
+	set_raw_clone_sizes(apotc_obj, count_raw_clone_sizes(
+		seurat_obj, get_idents(apotc_obj), get_clonecall(apotc_obj)
+	))
+}
+
+# assume apotc_obj has correct ident levels
+addInitialCentroids <- function(apotc_obj, seurat_obj) {
+	initial_centroids <- get_cluster_centroids(
+		seurat_obj, get_reduction_base(apotc_obj), get_idents(apotc_obj)
+	)
+
+	apotc_obj@centroids <- apotc_obj@label_coords <- initial_centroids
+	apotc_obj
 }
 
 # pack the clones assuming centroids are present
@@ -141,13 +162,11 @@ circlepackClones <- function(apotc_obj, ORDER, try_place, verbose) {
 		}
 		apotc_obj@centroids[[i]] <- list()
 		apotc_obj@label_coords[[i]] <- list()
-		# colors ignored, should have some way to match with seurat colors
 	}
 
 	apotc_obj
 }
 
-# function to do repulsion for both cases
 repulseClusters <- function(
 	apotc_obj, repulsion_threshold, repulsion_strength, max_repulsion_iter,
 	verbose
@@ -191,12 +210,70 @@ convert_to_rad_decrease <- function(clone_scale_factor, rad_scale_factor) {
 
 # checkers
 
+is_valid_cluster <- function(apotc_obj, cluster_ind) {
+	cluster_ind %>% is_bound_between(1, get_num_clusters(apotc_obj))
+}
+
 is_valid_nonempty_cluster <- function(apotc_obj, cluster_ind) {
 	typecheck(cluster_ind, is_an_integer)
-	is_bound_between(cluster_ind, 1, get_num_clusters(apotc_obj)) &&
+	is_valid_cluster(apotc_obj, cluster_ind) &&
 		isnt_empty(get_clusterlists(apotc_obj)[[cluster_ind]])
 }
 
+have_default_idents <- function(apotc_obj) {
+	identical(get_idents(apotc_obj), as.character(1:get_num_clusters(apotc_obj)))
+}
+
+# functions for matching clusters and clonotypes
+
+match_clonotypes_to_sizes <- function(apotc_obj, clonotypes, as_table = FALSE) {
+	get_aggregated_clone_sizes(apotc_obj)[clonotypes] %>%
+		ifelse(!as_table, identity, convert_named_numeric_to_table)()
+}
+
+# match a cluster either by index or label
+match_index <- function(apotc_obj, index) {
+
+	varname <- deparse(substitute(index))
+
+	if (is_integer(index)) {
+		if(all(sapply(index, function(x) is_valid_cluster(apotc_obj, x)))) {
+			return(index)
+		}
+		stop(call. = FALSE,
+			"Some or all indices in `", varname, "` ", #FIXME likely wrong varname
+			"are out of bounds of the APackOfTheClones Run."
+		)
+	}
+
+	# assume character of names
+	labels <- get_labels(apotc_obj)
+	output <- integer(length(labels))
+
+	for (i in seq_along(index)) {
+
+		location <- which(labels == index[i]) # TODO check invalid labels
+
+		if (length(location) == 0) {
+			stop(call. = FALSE,
+				"No label matched the input string"
+			)
+		}
+
+		if (length(location) > 1) {
+			warning(call. = FALSE,
+				"* label '", index[i], "' ",
+				"had multiple matches in the APackOfTheClones run, ",
+				"using the first occurence at index ", location[1]
+			)
+		}
+
+		output[i] <- location[1]
+	}
+
+	output
+}
+
 # getters
 
 get_reduction_base <- function(apotc_obj) {
@@ -211,6 +288,14 @@ get_metadata_filter_string <- function(apotc_obj) {
 	apotc_obj@metadata_filter_string
 }
 
+get_idents <- function(apotc_obj) {
+	apotc_obj@idents
+}
+
+get_ident_index <- function(apotc_obj, ident_lvl) {
+	which(get_idents(apotc_obj) %in% ident_lvl)
+}
+
 get_clusterlists <- function(apotc_obj) {
 	apotc_obj@clusters
 }
@@ -224,8 +309,6 @@ get_raw_clone_sizes <- function(apotc_obj, as_hash = FALSE) {
 	hash_from_tablelist(apotc_obj@clone_sizes)
 }
 
-# get all clone sizes as a single table
-# TODO unsure what happens with no clones
 get_aggregated_clone_sizes <- function(
 	apotc_obj, sort_decreasing = NULL, get_top = NULL
 ) {
@@ -237,9 +320,8 @@ get_aggregated_clone_sizes <- function(
 	filter_top_clones(clone_sizes, get_top)
 }
 
-# S3 generic method to get clonotypes
 get_unique_clonotypes <- function(x) {
-	unique(unlist(lapply(get_raw_clone_sizes(x), names)))
+	unique(unlist(lapply(unname(get_raw_clone_sizes(x)), names)))
 }
 
 get_processed_clone_sizes <- function(apotc_obj) {
@@ -259,9 +341,7 @@ get_num_clones <- function(apotc_obj) {
 	sum(unlist(get_raw_clone_sizes(apotc_obj)))
 }
 
-get_num_clusters <- function(apotc_obj) {
-	apotc_obj@num_clusters
-}
+get_num_clusters <- function(apotc_obj) length(get_idents(apotc_obj))
 
 get_valid_num_clusters <- function(apotc_obj) {
 	n <- 0
@@ -307,6 +387,16 @@ set_metadata_filter_string <- function(apotc_obj, extra_filter) {
 	apotc_obj
 }
 
+set_idents <- function(apotc_obj, x) {
+	apotc_obj@idents <- as.character(x)
+	apotc_obj
+}
+
+set_raw_clone_sizes <- function(apotc_obj, x) {
+	apotc_obj@clone_sizes <- x
+	apotc_obj
+}
+
 set_clone_scale_factor <- function(apotc_obj, x) {
 	apotc_obj@clone_scale_factor <- x
 	apotc_obj
@@ -320,3 +410,13 @@ set_clusterlists <- function(apotc_obj, x) {
 lapply_clusterlists <- function(apotc_obj, f) {
 	set_clusterlists(apotc_obj, lapply(get_clusterlists(apotc_obj), f))
 }
+
+set_cluster_colors <- function(apotc_obj, x) {
+	apotc_obj@cluster_colors <- x
+	apotc_obj
+}
+
+set_labels <- function(apotc_obj, x) {
+	apotc_obj@labels <- x
+	apotc_obj
+}
