@@ -1,5 +1,231 @@
-# script to manage the interface for accessing the apotc data
-# all functions assume arguments are correct
+#' @title
+#' Check for the existence of an APackOfTheClones run with its run id
+#'
+#' @description
+#' `r lifecycle::badge("stable")`
+#'
+#' A convenience function to check for the existence of an APackOfTheClones
+#' run with its run id, regardless of if any run has been made
+#'
+#' @param seurat_obj a seurat object
+#' @param run_id character. The id of the associated ApotcRun.
+#'
+#' @return A logical indicating whether the run exists.
+#' @export
+#'
+#' @examples
+#' pbmc <- RunAPOTC(
+#'     seurat_obj = get(data("combined_pbmc")),
+#'     reduction_base = "umap",
+#'     clonecall = "strict",
+#'     run_id = "run1",
+#'     verbose = FALSE
+#' )
+#'
+#' containsApotcRun(pbmc, "run1")
+#' #> [1] TRUE
+#'
+#' containsApotcRun(pbmc, "run2")
+#' #> [1] FALSE
+#'
+containsApotcRun <- function(seurat_obj, run_id) {
+
+    if (!is_seurat_object(seurat_obj)) stop("input must be a seurat object")
+    typecheck(run_id, is_a_character)
+
+    if (!containsAnyApotcData(seurat_obj)) {
+        return(FALSE)
+    }
+
+    any(getApotcDataIds(seurat_obj) == run_id)
+}
+
+#' @title
+#' Rename an APackOfTheClones run
+#'
+#' @description
+#' `r lifecycle::badge("stable")`
+#'
+#' A function to rename an APackOfTheClones run identified by its run id in
+#' a Seurat object.
+#'
+#' @param seurat_obj A Seurat object containing APackOfTheClones data - the
+#' output of [RunAPOTC]
+#' @param old_run_id Character. The current id of the APackOfTheClones run to
+#' be renamed.
+#' @param new_run_id Character. The new id to assign to the APackOfTheClones
+#' run.
+#'
+#' @return A Seurat object with the APackOfTheClones run renamed.
+#' @export
+#'
+#' @examples
+#' pbmc <- RunAPOTC(
+#'     seurat_obj = get(data("combined_pbmc")),
+#'     reduction_base = "umap",
+#'     clonecall = "strict",
+#'     run_id = "run1",
+#'     verbose = FALSE
+#' )
+#'
+#' pbmc <- renameApotcRun(pbmc, "run1", "new_run")
+#' # Now "run1" has been renamed to "new_run"
+#'
+renameApotcRun <- function(seurat_obj, old_run_id, new_run_id) {
+
+    if (!is_seurat_object(seurat_obj)) stop("input must be a seurat object")
+    typecheck(old_run_id, is_a_character)
+    typecheck(new_run_id, is_a_character)
+
+    if (!containsApotcRun(seurat_obj, old_run_id))
+        stop("There's no run named `", old_run_id, "`")
+    if (containsApotcRun(seurat_obj, new_run_id))
+        stop("There is already a run named `", new_run_id, "`")
+
+    names(seurat_obj@misc$APackOfTheClones)[
+        getApotcDataIds(seurat_obj) == old_run_id
+    ] <- new_run_id
+
+    seurat_obj
+}
+
+#' @title
+#' Delete the results of an APackOfTheClones run
+#'
+#' @description
+#' `r lifecycle::badge("stable")`
+#'
+#' A convenience function to erase all data associated with a particular run,
+#' including the ApotcData and command in seurat_obj@command. The run_id would
+#' be no longer accessible afterwards.
+#'
+#' @param seurat_obj a seurat object that has had RunAPOTC ran on it before in
+#' order of the functions being called.
+#' @param run_id character. The id of the associated ApotcRun.
+#'
+#' @return The modified input seurat object
+#' @export
+#'
+#' @examples
+#' pbmc <- RunAPOTC(
+#'     seurat_obj = get(data("combined_pbmc")),
+#'     reduction_base = "umap",
+#'     clonecall = "strict",
+#'     run_id = "run1",
+#'     verbose = FALSE
+#' )
+#'
+#' getApotcDataIds(pbmc)
+#' #> [1] "run1"
+#'
+#' # delete the data
+#' pbmc <- deleteApotcData(pbmc, "run1")
+#'
+#' getApotcDataIds(pbmc)
+#' #> NULL
+#'
+deleteApotcData <- function(seurat_obj, run_id) {
+
+    if (!is_seurat_object(seurat_obj)) stop("input must be a seurat object")
+    if (length(run_id) != 1) stop("the `run_id` argument must be of length 1")
+    if (!containsApotcRun(seurat_obj, run_id)) {
+        stop(paste("no run with id:", run_id, "is present"))
+    }
+
+    seurat_obj <- setApotcData(seurat_obj, run_id, NULL)
+    seurat_obj@commands[[get_command_name("RunAPOTC", run_id)]] <- NULL
+    seurat_obj
+}
+
+#' @title
+#' Get all run ids of previous RunAPOTC runs on a seurat object
+#'
+#' @description
+#' `r lifecycle::badge("stable")`
+#'
+#' A convenience function to get all run ids of previous RunAPOTC run IDs
+#'
+#' @param seurat_obj a seurat object that has had RunAPOTC ran on it before in
+#' order of the functions being called.
+#'
+#' @return a character vector of all run ids of previous RunAPOTC runs, in
+#' the order they were ran in. If there are no runs on the object, it returns
+#' `NULL`.
+#' @export
+#'
+#' @examples
+#' pbmc <- RunAPOTC(
+#'     seurat_obj = get(data("combined_pbmc")),
+#'     reduction_base = "umap",
+#'     clonecall = "strict",
+#'     verbose = FALSE
+#' )
+#'
+#' getApotcDataIds(pbmc)
+#' #> [1] "umap;CTstrict;_;_"
+#'
+#' pbmc <- RunAPOTC(
+#'     seurat_obj = pbmc,
+#'     reduction_base = "umap",
+#'     clonecall = "gene",
+#'     verbose = FALSE
+#' )
+#'
+#' getApotcDataIds(pbmc)
+#' #> [1] "umap;CTstrict;_;_" "umap;CTgene;_;_"
+#'
+getApotcDataIds <- function(seurat_obj) {
+    if (!is_seurat_object(seurat_obj)) stop("input must be a seurat object")
+    ids <- names(seurat_obj@misc[["APackOfTheClones"]])
+    if (identical(ids, character(0)) || is.null(ids)) return(NULL)
+    ids
+}
+
+#' @title
+#' Get the object id of the most recent RunAPOTC run on a seurat object
+#'
+#' @description
+#' `r lifecycle::badge("stable")`
+#'
+#' A convenience function to get the object id of the most recent valid
+#' [RunAPOTC] run, to be used by [APOTCPlot] and [AdjustAPOTC]
+#'
+#' @param seurat_obj a seurat object that has had RunAPOTC ran on it before in
+#' order of the functions being called.
+#'
+#' @return a character of the object id of the last [RunAPOTC] call
+#' @export
+#'
+#' @examples
+#' # first run
+#' pbmc <- RunAPOTC(
+#'     seurat_obj = get(data("combined_pbmc")),
+#'     reduction_base = "umap",
+#'     clonecall = "strict",
+#'     verbose = FALSE
+#' )
+#'
+#' getLastApotcDataId(pbmc)
+#' #> [1] "umap;CTstrict;_;_"
+#'
+#' # second run with a different clonecall
+#' pbmc <- RunAPOTC(
+#'     seurat_obj = pbmc,
+#'     reduction_base = "umap",
+#'     clonecall = "gene",
+#'     verbose = FALSE
+#' )
+#'
+#' getLastApotcDataId(pbmc)
+#' #> [1] "umap;CTgene;_;_"
+#'
+getLastApotcDataId <- function(seurat_obj) {
+    getlast(getApotcDataIds(seurat_obj))
+}
+
+# TODO change object ids-make it all nonempty arguments
+
+# object id generation:
 
 # from the input of RunAPOTC, convert the condition to a call to be put in
 # @meta.data %>% dpylr::filter(eval(parse(text = "output of this func")))
@@ -27,6 +253,9 @@ parse_to_metadata_filter_str <- function(metadata_filter, varargs_list) {
 
     filter_string <- sort_and_join_conds_by_and(filter_strings)
 
+    # TODO FIXME - this will allow symbolic filtering as well
+    #metadata_filter <- convert_to_string_if_expr(deparse(substitute(metadata_filter)))
+
     if (is_valid_filter_str(metadata_filter)) {
         filter_string <- paste(
             "(", filter_string, ")&(", metadata_filter, ")", sep = ""
@@ -78,6 +307,11 @@ sort_and_join_conds_by_and <- function(filter_strings) {
     )
 }
 
+# if symbolic, convert to filter string
+convert_to_string_if_expr <- function(deparsed_metadata_filter) {
+   gsub("\"", "'", deparsed_metadata_filter)
+}
+
 # functions for converting args of RunAPOTC to the apotc data sample id
 # stored under under @misc[["APackOfTheClones"]][[id]]
 infer_object_id_if_needed <- function(args, varargs_list) {
@@ -198,25 +432,33 @@ getLastApotcData <- function(seurat_obj) {
     getApotcData(seurat_obj, getLastApotcDataId(seurat_obj))
 }
 
-# get or create apotcdata - assume obj_id is a auto-generated id
-getApotcDataIfExistsElseCreate <- function(seurat_obj, obj_id) {
-    if (containsApotcRun(seurat_obj, obj_id)) {
+getApotcDataIfExistsElseCreate <- function(seurat_obj, obj_id, arglist, ...) {
+
+    if (!is.null(obj_id)) {
+        if (!containsApotcRun(seurat_obj, obj_id)) {
+            stop(call. = FALSE, "No runs found with the id: `", obj_id, "`")
+        }
         return(getApotcData(seurat_obj, obj_id))
     }
 
-    # assume is a default autogenerated id
-    arglist <- deparse_object_id(obj_id)
+    if (is_an_integer(arglist)) arglist <- parent.frame(arglist)
+    if (is.null(arglist)) arglist <- parent.frame()
+
     actual_metadata_filter <- parse_to_metadata_filter_str(
-        arglist$extra_filter, arglist$varargs_list
+        arglist$extra_filter, list(...)
     )
 
-    getLastApotcData(RunAPOTC(
-        seurat_obj,
-        reduction_base = arglist$reduction_base,
-        clonecall = arglist$clonecall,
-        extra_filter = actual_metadata_filter,
-        verbose = FALSE
-    ))
+    seurat_obj %>%
+        RunAPOTC(
+            reduction_base = arglist$reduction_base,
+            clonecall = arglist$clonecall,
+            extra_filter = actual_metadata_filter,
+            alt_ident = arglist$alt_ident,
+            run_id = "__getApotcDataIfExistsElseCreate__",
+            override = TRUE,
+            verbose = FALSE
+        ) %>%
+        getApotcData("__getApotcDataIfExistsElseCreate__")
 }
 
 setApotcData <- function(seurat_obj, obj_id, apotc_obj) {
@@ -227,179 +469,3 @@ setApotcData <- function(seurat_obj, obj_id, apotc_obj) {
 containsAnyApotcData <- function(seurat_obj) {
     !is.null(getApotcDataIds(seurat_obj))
 }
-
-#' @title
-#' Check for the existence of an APackOfTheClones run with its run id
-#'
-#' @description
-#' `r lifecycle::badge("stable")`
-#'
-#' A convenience function to check for the existence of an APackOfTheClones
-#' run with its run id, regardless of if any run has been made
-#'
-#' @param seurat_obj a seurat object
-#' @param run_id character. The id of the associated ApotcRun.
-#'
-#' @return A logical indicating whether the run exists.
-#' @export
-#'
-#' @examples
-#' pbmc <- RunAPOTC(
-#'     seurat_obj = get(data("combined_pbmc")),
-#'     reduction_base = "umap",
-#'     clonecall = "strict",
-#'     run_id = "run1",
-#'     verbose = FALSE
-#' )
-#'
-#' containsApotcRun(pbmc, "run1")
-#' #> [1] TRUE
-#'
-#' containsApotcRun(pbmc, "run2")
-#' #> [1] FALSE
-#'
-containsApotcRun <- function(seurat_obj, run_id) {
-
-    if (!is_seurat_object(seurat_obj)) stop("input must be a seurat object")
-    if (length(run_id) != 1) stop("the `run_id` argument must be of length 1")
-
-    if (!containsAnyApotcData(seurat_obj)) {
-        return(FALSE)
-    }
-
-    any(getApotcDataIds(seurat_obj) == run_id)
-}
-
-#' @title
-#' Delete the results of an APackOfTheClones run
-#'
-#' @description
-#' `r lifecycle::badge("stable")`
-#'
-#' A convenience function to erase all data associated with a particular run,
-#' including the ApotcData and command in seurat_obj@command. The run_id would
-#' be no longer accessible afterwards.
-#'
-#' @param seurat_obj a seurat object that has had RunAPOTC ran on it before in
-#' order of the functions being called.
-#' @param run_id character. The id of the associated ApotcRun.
-#'
-#' @return The modified input seurat object
-#' @export
-#'
-#' @examples
-#' pbmc <- RunAPOTC(
-#'     seurat_obj = get(data("combined_pbmc")),
-#'     reduction_base = "umap",
-#'     clonecall = "strict",
-#'     run_id = "run1",
-#'     verbose = FALSE
-#' )
-#'
-#' getApotcDataIds(pbmc)
-#' #> [1] "run1"
-#'
-#' # delete the data
-#' pbmc <- deleteApotcData(pbmc, "run1")
-#'
-#' getApotcDataIds(pbmc)
-#' #> NULL
-#'
-deleteApotcData <- function(seurat_obj, run_id) {
-
-    if (!is_seurat_object(seurat_obj)) stop("input must be a seurat object")
-    if (length(run_id) != 1) stop("the `run_id` argument must be of length 1")
-    if (!containsApotcRun(seurat_obj, run_id)) {
-        stop(paste("no run with id:", run_id, "is present"))
-    }
-
-    seurat_obj <- setApotcData(seurat_obj, run_id, NULL)
-    seurat_obj@commands[[get_command_name("RunAPOTC", run_id)]] <- NULL
-    seurat_obj
-}
-
-#' @title
-#' Get all run ids of previous RunAPOTC runs on a seurat object
-#'
-#' @description
-#' `r lifecycle::badge("stable")`
-#'
-#' A convenience function to get all run ids of previous RunAPOTC run IDs
-#'
-#' @param seurat_obj a seurat object that has had RunAPOTC ran on it before in
-#' order of the functions being called.
-#'
-#' @return a character vector of all run ids of previous RunAPOTC runs, in
-#' the order they were ran in. If there are no runs on the object, it returns
-#' `NULL`.
-#' @export
-#'
-#' @examples
-#' pbmc <- RunAPOTC(
-#'     seurat_obj = get(data("combined_pbmc")),
-#'     reduction_base = "umap",
-#'     clonecall = "strict",
-#'     verbose = FALSE
-#' )
-#'
-#' getApotcDataIds(pbmc)
-#' #> [1] "umap;CTstrict;_;_"
-#'
-#' pbmc <- RunAPOTC(
-#'     seurat_obj = pbmc,
-#'     reduction_base = "umap",
-#'     clonecall = "gene",
-#'     verbose = FALSE
-#' )
-#'
-#' getApotcDataIds(pbmc)
-#' #> [1] "umap;CTstrict;_;_" "umap;CTgene;_;_"
-#'
-getApotcDataIds <- function(seurat_obj) {
-    if (!is_seurat_object(seurat_obj)) stop("input must be a seurat object")
-    ids <- names(seurat_obj@misc[["APackOfTheClones"]])
-    if (identical(ids, character(0)) || is.null(ids)) return(NULL)
-    ids
-}
-
-#' @title
-#' Get the object id of the most recent RunAPOTC run on a seurat object
-#'
-#' @description
-#' `r lifecycle::badge("stable")`
-#' 
-#' A convenience function to get the object id of the most recent valid
-#' [RunAPOTC] run, to be used by [APOTCPlot] and [AdjustAPOTC]
-#'
-#' @param seurat_obj a seurat object that has had RunAPOTC ran on it before in
-#' order of the functions being called.
-#'
-#' @return a character of the object id of the last [RunAPOTC] call
-#' @export
-#'
-#' @examples
-#' # first run
-#' pbmc <- RunAPOTC(
-#'     seurat_obj = get(data("combined_pbmc")),
-#'     reduction_base = "umap",
-#'     clonecall = "strict",
-#'     verbose = FALSE
-#' )
-#'
-#' getLastApotcDataId(pbmc)
-#' #> [1] "umap;CTstrict;_;_"
-#'
-#' # second run with a different clonecall
-#' pbmc <- RunAPOTC(
-#'     seurat_obj = pbmc,
-#'     reduction_base = "umap",
-#'     clonecall = "gene",
-#'     verbose = FALSE
-#' )
-#'
-#' getLastApotcDataId(pbmc)
-#' #> [1] "umap;CTgene;_;_"
-#'
-getLastApotcDataId <- function(seurat_obj) {
-    getlast(getApotcDataIds(seurat_obj))
-}
