@@ -31,7 +31,7 @@
 removeLegend <- function(apotc_ggplot) {
     check_is_apotc_ggplot(apotc_ggplot)
     if (!has_legend(apotc_ggplot)) return(apotc_ggplot)
-    remove_ggplot_layers(apotc_ggplot, get_legend_layer_indicies(apotc_ggplot))
+    remove_ggplot_layers(apotc_ggplot, get_legend_layer_indices(apotc_ggplot))
 }
 
 #' @title overlay a clone size legend on an APackOfTheClones plot
@@ -66,6 +66,8 @@ removeLegend <- function(apotc_ggplot) {
 #' @seealso [removeLegend]
 #'
 #' @examples
+#' library(magrittr)
+#'
 #' # create a plot with a legend
 #' apotc_plot <- vizAPOTC(get(data("combined_pbmc")), verbose = FALSE)
 #'
@@ -73,7 +75,7 @@ removeLegend <- function(apotc_ggplot) {
 #' overlayLegend(apotc_plot, legend_position = "top right")
 #'
 #' # use different sizes and label - may be nice to use the pipe
-#' apotc_plot |> overlayLegend(
+#' apotc_plot %>% overlayLegend(
 #'     legend_sizes = c(1, 3, 7, 9),
 #'     legend_label = "odd sizes"
 #' )
@@ -191,22 +193,22 @@ get_layers_after_legend <- function(apotc_ggplot) {
     layers[(get_last_legend_layer_index(apotc_ggplot) + 1):length(layers)]
 }
 
-get_legend_layer_indicies <- function(apotc_ggplot) {
+get_legend_layer_indices <- function(apotc_ggplot) {
     which(names(apotc_ggplot$layers) == .ApotcLegendLayerName)
 }
 
 get_first_legend_layer_index <- function(apotc_ggplot) {
-    get_legend_layer_indicies(apotc_ggplot)[1]
+    get_legend_layer_indices(apotc_ggplot)[1]
 }
 
 get_last_legend_layer_index <- function(apotc_ggplot) {
-    getlast(get_legend_layer_indicies(apotc_ggplot))
+    getlast(get_legend_layer_indices(apotc_ggplot))
 }
 
 remove_legend_and_layers_after <- function(apotc_ggplot) {
     num_layers <- length(apotc_ggplot$layers)
-    removal_indicies <- get_first_legend_layer_index(apotc_ggplot):num_layers
-    apotc_ggplot$layers[removal_indicies] <- NULL
+    removal_indices <- get_first_legend_layer_index(apotc_ggplot):num_layers
+    apotc_ggplot$layers[removal_indices] <- NULL
     apotc_ggplot
 }
 
