@@ -1,5 +1,7 @@
+data("combined_pbmc")
 non_subset_apotc_data <- ApotcData(
-	seurat_obj = get(data("combined_pbmc")),
+	seurat_obj = combined_pbmc,
+	alt_ident = NULL,
 	metadata_filter_condition = "",
 	clonecall = "CTstrict",
 	reduction_base = "umap",
@@ -7,6 +9,10 @@ non_subset_apotc_data <- ApotcData(
 	rad_scale_factor = 0.95
 )
 
+test_that("have_default_idents work", {
+	expect_true(have_default_idents(non_subset_apotc_data))
+})
+
 expect_common_apotc_els_equal <- function(test_apotc_data) {
 
 	expect_equal(
@@ -15,7 +21,7 @@ expect_common_apotc_els_equal <- function(test_apotc_data) {
 	)
 	expect_equal(test_apotc_data@clonecall, non_subset_apotc_data@clonecall)
 	
-	expect_equal(test_apotc_data@num_clusters, non_subset_apotc_data@num_clusters)
+	expect_equal(get_num_clusters(test_apotc_data), get_num_clusters(non_subset_apotc_data))
 
 	expect_equal(
 		test_apotc_data@clone_scale_factor, non_subset_apotc_data@clone_scale_factor
@@ -51,7 +57,7 @@ test_that("The default case ApotcData constructor works", {
 		getdata("get_clone_sizes", "raw_strict_clone_sizes")
 	)
 
-	expect_equal(test_apotc_data@num_clusters, 17)
+	expect_equal(get_num_clusters(test_apotc_data), 17)
 
 	expect_equal(test_apotc_data@clone_scale_factor, 0.300051)
 	expect_equal(test_apotc_data@rad_scale_factor, 0.95)
@@ -67,10 +73,28 @@ test_that("The default case ApotcData constructor works", {
 
 })
 
+test_that("changing active ident affects clustering", {
+
+	test_apotc <- ApotcData(
+		seurat_obj = combined_pbmc,
+		alt_ident = "seurat_clusters",
+		metadata_filter_condition = "",
+		clonecall = "CTstrict",
+		reduction_base = "umap",
+		clone_scale_factor = 0.300051,
+		rad_scale_factor = 0.95
+	)
+
+	expect_common_apotc_els_equal(test_apotc)
+
+	# TODO more tests on custom ident
+})
+
 test_that("The subset case ApotcData constructor works", {
 
 	test_apotc_data <- ApotcData(
-		seurat_obj = get(data("combined_pbmc")),
+		seurat_obj = combined_pbmc,
+		alt_ident = NULL,
 		metadata_filter_condition = "seurat_clusters != 1",
 		clonecall = "CTstrict",
 		reduction_base = "umap",
@@ -101,7 +125,8 @@ test_that("The subset case ApotcData constructor works", {
 test_that("ApotcData subsetting works for 1 seurat cluster", {
 
 	test_apotc_data <- ApotcData(
-		seurat_obj = get(data("combined_pbmc")),
+		seurat_obj = combined_pbmc,
+		alt_ident = NULL,
 		metadata_filter_condition = "seurat_clusters == 4",
 		clonecall = "CTstrict",
 		reduction_base = "umap",
@@ -168,7 +193,8 @@ test_that("circlepackClones packs right for the default case", {
 test_that("circlepackClones works for the subset case", {
 
 	test_apotc_data <- ApotcData(
-		seurat_obj = get(data("combined_pbmc")),
+		seurat_obj = combined_pbmc,
+		alt_ident = NULL,
 		metadata_filter_condition = "seurat_clusters != 1",
 		clonecall = "CTstrict",
 		reduction_base = "umap",
@@ -209,7 +235,8 @@ test_that("circlepackClones packs right for the subset case", {
 	skip_on_cran()
 	
 	test_apotc_data <- ApotcData(
-		seurat_obj = get(data("combined_pbmc")),
+		seurat_obj = combined_pbmc,
+		alt_ident = NULL,
 		metadata_filter_condition = "seurat_clusters != 1",
 		clonecall = "CTstrict",
 		reduction_base = "umap",
@@ -230,5 +257,26 @@ test_that("circlepackClones packs right for the subset case", {
 })
 
 # TODO test the repulsion API
+
+test_that("match_clonotypes_to_sizes works", {
+
+	a <- getLastApotcData(RunAPOTC(combined_pbmc, verbose = FALSE))
+
+	expect_equal(
+		match_clonotypes_to_sizes(a, get_unique_clonotypes(a)),
+		get_aggregated_clone_sizes(a)
+	)
+})
+
+test_that("match_index works", {
+
+	expect_identical(match_index(non_subset_apotc_data, 1:17), 1:17)
+
+	expect_identical(
+		match_index(non_subset_apotc_data, index = gen_labels(17)), 1:17
+	)
+
+})
+
 # TODO test getters and setters
 # TODO test edgecases
