@@ -1,14 +1,14 @@
 test_that("basic typechecking works", {
 
-  x <- 10
-  y <- list(x = 10)
+  a <- 10
+  y <- list(a = 10)
   z <- rep(8, 31)
 
-  expect_null(typecheck(x, is_an_integer, is_integer, is_a_numeric))
+  expect_null(typecheck(a, is_an_integer, is_integer, is_a_numeric))
 
   expect_error(
-    object = typecheck(x, is_a_character),
-    "`x` must be a character of length 1"
+    object = typecheck(a, is_a_character),
+    "`a` must be a character of length 1"
   )
 
   expect_error(
@@ -16,11 +16,11 @@ test_that("basic typechecking works", {
     "`y` must be an integer of length 1"
   )
 
-  expect_null(typecheck(y$x, is_integer))
+  expect_null(typecheck(y$a, is_integer))
 
   expect_error(
-    object = typecheck(y$x, is_a_character),
-    "`x` must be a character of length 1"
+    object = typecheck(y$a, is_a_character),
+    "`a` must be a character of length 1"
   )
 
   expect_error(
